import 'package:flutter/material.dart';
import '../../common/values/styles.dart';
import '../custom/spaces.dart';
import '../text/custom_text_medium_bold_field.dart';
import '../text/custom_text_medium_field.dart';

class CustomDialogSignOut extends StatelessWidget {
  final String title, content, positiveBtnText, negativeBtnText;
  final GestureTapCallback positiveBtnPressed;

  CustomDialogSignOut({
    required this.title,
    required this.content,
    required this.positiveBtnText,
    required this.negativeBtnText,
    required this.positiveBtnPressed,
  });

  @override
  Widget build(BuildContext context) {
    return Dialog(
      elevation: 0,
      backgroundColor: Colors.transparent,
      child: _buildDialogContent(context),
    );
  }

  Widget _buildDialogContent(BuildContext context) {
    return Stack(
      alignment: Alignment.topCenter,
      children: <Widget>[
        Container(
          margin:
              EdgeInsets.only(top: 40), // to push the box half way below circle
          decoration: BoxDecoration(
            color: Colors.white,
            borderRadius: BorderRadius.circular(12),
            boxShadow: [
              BoxShadow(
                color: Colors.grey.withOpacity(0.5),
                spreadRadius: 5,
                blurRadius: 7,
                offset: Offset(0, 3), // changes position of shadow
              ),
            ],
          ),
          padding: EdgeInsets.only(
              top: 20, left: 20, right: 20), // spacing inside the box
          child: Column(
            mainAxisSize: MainAxisSize.min,
            children: <Widget>[
              CustomTextMediumBoldField(label: title),
              SpaceH16(),
              CustomTextMediumField(label: content),
              SpaceH10(),
              Row(
                mainAxisSize: MainAxisSize.max,
                mainAxisAlignment: MainAxisAlignment.spaceEvenly,
                children: <Widget>[
                  Expanded(
                    flex: 1,
                    child: TextButton(
                      child: Text(
                        negativeBtnText,
                        style: Styles.customTextMediumStyle(
                            color: Theme.of(context).buttonColor),
                      ),
                      onPressed: () => Navigator.of(context).pop(),
                    ),
                  ),
                  Expanded(
                    flex: 1,
                    child: TextButton(
                      child: Text(positiveBtnText,
                          style: Styles.customTextMediumStyle(
                              color: Theme.of(context).buttonColor)),
                      onPressed: positiveBtnPressed,
                    ),
                  )
                ],
              ),
            ],
          ),
        ),
      ],
    );
  }
}
